@@ -19,7 +19,7 @@ def pytest_configure(config):
         return
 
     config.sherlock = Sherlock(config)
-    config.pluginmanager.register(config.sherlock, "sherlock")
+    config.pluginmanager.register(config.sherlock)
 
 
 def pytest_report_teststatus(report):
